# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-01-14 06:18
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('bee_django_exam', '0005_auto_20180114_1417'),
    ]

    operations = [
        migrations.AlterModelTable(
            name='userexamrecord',
            table='bee_django_exam_user_exam_record',
        ),
    ]
