{% extends "bee_django_exam/base.html" %}
{% load static %}
{% block content %}
    <form method="post">
        {% csrf_token %}
        {{ form.as_ul }}


        <input type="submit" value="提交"/>
    </form>
{% endblock %}


{% block scripts %}
    <script>

    </script>
{% endblock %}